import pytest
from snappy.snappy import Snappy

class TestSnappy:
    
    # Uncomment to perform snapshot test
    # def test_snappy_snap_roots(self):
        
    #     # Arrange
    #     instances = ["172.31.255.50", "172.31.255.20"]
    #     tags_specifications = [{
    #         "Key": "CreatorName",
    #         "Value": "mervin.hemaraju@checkout.com"
    #     }]
        
    #     # Act
    #     try:
    #         snappy = Snappy(instances)
            
    #         snapshots = snappy.snap_roots(tags_specifications)
            
    #         print(f"test_snappy_snap_roots: {snapshots}")
            
    #     except Exception as e:
    #         result = str(e)
            
    #         print(f"test_snappy_snap_roots: {result}")
            
    #     # Assert
    #     assert False
            
    testdata = [
        
        #### -> Testing for Mixed hostnames and ip addresses
        (["172.31.255.50", "172.31.255.20"], "Passed", 2),
        (["172.31.255.50", "172.31.255.20", "lin_jump_pub_01"], "Passed", 3),
        (["win_ad_01", "win_jump_pub_01", "lin_jump_pub_01"], "Passed", 3),
        (["172.31.255.50", "10.0.0.0"], "The following instances could not be retrieved: ['10.0.0.0']", 0),
        (["win_jump_pub_01", "winlin_jump_pub_01"], "The following instances could not be retrieved: ['winlin_jump_pub_01']", 0),
        (["win_jump_pub_01", "172.31.255.50", "winlin_jump_pub_01"], "The following instances could not be retrieved: ['winlin_jump_pub_01']", 0),
        (["win_jump_pub_01", "10.0.0.0", "winlin_jump_pub_01"], "The following instances could not be retrieved: ['10.0.0.0', 'winlin_jump_pub_01']", 0),
        (["172.31.255.30", "172.31.255.50", "winlin_jump_pub_01"], "The following instances could not be retrieved: ['winlin_jump_pub_01']", 0),
        (["win_jump_pub_01", "10.0.0.0"], "The following instances could not be retrieved: ['10.0.0.0']", 0),
        
        #### -> Testing for Duplicates
        (["172.31.255.50", "172.31.255.50", "172.31.255.20"], "Passed", 2),
        (["172.31.255.50", "172.31.255.50", "172.31.255.50"], "Passed", 1),
        (["lin_jump_pub_01", "172.31.255.30", "172.31.255.30"], "Passed", 1),
        (["lin_jump_pub_01", "172.31.255.30", "172.31.255.20"], "Passed", 2),
    ]
    @pytest.mark.parametrize("test_data,expected_result,expected_size", testdata)
    def test_snappy_initialization(self,test_data,expected_result,expected_size):
        # Arrange
        
        # Act
        try:
            snappy = Snappy(test_data)
            result = "Passed"
        except Exception as e:
            result = str(e)
            
        # Assert
        assert result == expected_result
        
        if result == "Passed":                
            assert len(snappy.instances) == expected_size
        


import pytest
from snappy.utils.helper import retrieve_failed_instances, is_an_ip_address, organize_instances, remove_duplicate_instances


###########################
####### Test Models #######
###########################
class MyInstanceT:
    
    def __init__(self, private_ip, name) -> None:
        self.private_ip = private_ip
        self.name = name
        
class TestHelper:
        
    testdata = [
        (
            ["10.10.10.1", "10.10.10.2","10.10.10.3", "10.10.10.4"], 
            [MyInstanceT("10.10.10.1", "test1"), MyInstanceT("10.10.10.3", "test2")], 
            ["10.10.10.2", "10.10.10.4"]
        ),
        (
            ["test1", "test2","test3"], 
            [MyInstanceT("10.10.10.1", "test1"), MyInstanceT("10.10.10.3", "test2")], 
            ["test3"]
        ),
        (
            ["10.10.10.1", "10.10.10.2","test3", "10.10.10.4"], 
            [MyInstanceT("10.10.10.1", "test1"), MyInstanceT("10.10.10.3", "test3")], 
            ["10.10.10.2", "10.10.10.4"]
        ),
        (
            ["10.10.10.1", "10.10.10.2","test3", "test4"], 
            [MyInstanceT("10.10.10.1", "test1"), MyInstanceT("10.10.10.3", "test3")], 
            ["10.10.10.2", "test4"]
        ),
        (
            ["10.10.10.1", "10.10.10.2"], 
            [MyInstanceT("10.10.10.1", "test1"), MyInstanceT("10.10.10.2", "test3")], 
            []
        ),
        (
            ["test1", "test3"], 
            [MyInstanceT("10.10.10.1", "test1"), MyInstanceT("10.10.10.2", "test3")], 
            []
        ),
    ]
    @pytest.mark.parametrize("previous_instances,retrieved_instances,expected_result", testdata)
    def test_retrieve_failed_instances(self, previous_instances, retrieved_instances, expected_result):  
        # Arrange
        
        # Act
        result = retrieve_failed_instances(previous_instances, retrieved_instances)
        
        # Assert
        assert expected_result == result


    testdata = [
        ("1.1.1.1", True),
        ("10.10.10.10", True),
        ("1.10.100.255", True),
        ("255.255.255.255", True),
        ("255.255.255.256", False),
        ("255.255.256.255", False),
        ("255.256.255.255", False),
        ("256.255.255.255", False),
        ("192.168.100.", False),
        ("300.168.100.1", False),
        ("1.168.100.300", False),
        ("192.168..1", False),
        ("192..1.1", False),
        (".1.1.1", False),
        ("hello.168.100.1", False),
        ("t.r.s.a", False),
        ("100.1.1.1:20", False),
    ]
    @pytest.mark.parametrize("test_data,expected_result", testdata)
    def test_is_an_ip_address(self,test_data,expected_result):
        # Arrange

        # Act
        result = is_an_ip_address(test_data)

        # Assert
        assert result == expected_result
        
    
    testdata = [
        (["1.1.1.1", "server_1", "server_2", "2.2.2.2"], ["1.1.1.1","2.2.2.2"], ["server_1", "server_2"]),
        (["1.1.1.1", "2.2.2.2"], ["1.1.1.1","2.2.2.2"], []),
        (["server_1", "server_2"], [], ["server_1", "server_2"]),
        ([], [], []),
        (["1.1.1.1", "server_1", "server_2", "2.2.2.2", "3.3.3.3"], ["1.1.1.1","2.2.2.2", "3.3.3.3"], ["server_1", "server_2"]),
    ]
    @pytest.mark.parametrize("test_data,expected_ips,expected_hostnames", testdata)
    def test_organize_instances(self,test_data,expected_ips,expected_hostnames):
        # Arrange

        # Act
        result_ips, result_hostnames = organize_instances(test_data)

        # Assert
        assert expected_ips == result_ips
        assert expected_hostnames == result_hostnames
        
    testdata = [
        (
            [MyInstanceT("1.1.1.1", ""),MyInstanceT("1.1.1.2", ""),MyInstanceT("1.1.1.1", ""),MyInstanceT("1.1.1.2", "")], 
            [MyInstanceT("1.1.1.1", ""),MyInstanceT("1.1.1.2", "")]
        ),
        ([MyInstanceT("1.1.1.1", ""),MyInstanceT("1.1.1.2", ""),MyInstanceT("1.1.1.1", ""),MyInstanceT("1.1.1.2", ""),MyInstanceT("1.1.1.2", "")], [MyInstanceT("1.1.1.1", ""),MyInstanceT("1.1.1.2", "")]),
        ([MyInstanceT("1.1.1.1", ""),MyInstanceT("1.1.1.2", ""),MyInstanceT("1.1.1.2", ""),MyInstanceT("1.1.1.2", "")], [MyInstanceT("1.1.1.1", ""),MyInstanceT("1.1.1.2", "")]),
        ([MyInstanceT("1.1.1.2", ""),MyInstanceT("1.1.1.2", ""),MyInstanceT("1.1.1.2", "")], [MyInstanceT("1.1.1.2", "")]),
        ([MyInstanceT("1.1.1.1", ""),MyInstanceT("1.1.1.2", ""),MyInstanceT("1.1.1.3", "")], [MyInstanceT("1.1.1.1", ""),MyInstanceT("1.1.1.2", ""),MyInstanceT("1.1.1.3", "")]),
    ]
    @pytest.mark.parametrize("test_data,expected_result", testdata)
    def test_remove_duplicate_instances(self,test_data, expected_result):
        
        # Act
        result = remove_duplicate_instances(test_data)
        
        # Assert
        assert [r.private_ip for r in result] == [er.private_ip for er in expected_result]
        assert len(result) == len(expected_result)


import re

from datetime import date

def format_today():
    # This function returns today's date
    # in the following format YYYYMMDD
    today = date.today()
    return today.strftime("%Y%m%d")

def retrieve_failed_instances(previous_instances, retrieved_instances):
    
    # Definition of failed instances
    failed_instances = []
    
    # Organize previous instances
    previous_ip_addresses, previous_hostnames = organize_instances(previous_instances)
    
    # Get retrieved instances
    retrieved_ip_addresses = [instance.private_ip for instance in retrieved_instances]
    retrieved_hostnames = [instance.name for instance in retrieved_instances]
    
    failed_instances = failed_instances + [instance for instance in previous_ip_addresses if (instance not in retrieved_ip_addresses and instance not in retrieved_hostnames)]
    failed_instances = failed_instances + [instance for instance in previous_hostnames if (instance not in retrieved_ip_addresses and instance not in retrieved_hostnames)]
    
    return failed_instances

def is_an_ip_address(data):
    # Checks whether a given string
    # has ip address format
    pat = re.match("^((25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$", data)
    return bool(pat)

def organize_instances(instances_raw):
    # Return ip_addresses, hostnames
    return [ip for ip in instances_raw if is_an_ip_address(ip)], [hostname for hostname in instances_raw if not is_an_ip_address(hostname)]

def remove_duplicate_instances(instances):
    
    # Remove duplicates in list of instances
    new_list = []
    
    for instance in instances:
        
        is_present = any(x.private_ip == instance.private_ip for x in new_list)

        if not is_present:
            new_list.append(instance)
    
    return new_list


import json
import snappy.utils.constants as Consts
from snappy.instance import Instance

class TestInstance:

    # Uncomment to perform snapshot test
    # def test_snap_root_NormalValues(self):
    #     # Arrange
    #     instance_json = json.load(open("tests/test_data/test_data_instance_for_snapshot_02.json"))
    #     tags_specifications = [{
    #         "Key": "CreatorName",
    #         "Value": "mervin.hemaraju@checkout.com"
    #     }]

    #     # Act
    #     instance = Instance(instance_json)
    #     snapshot = instance.snap_root(tags_specifications=tags_specifications)
    #     print(f"test_snap_root_NormalValues: {snapshot}")

    #     assert False
    
    # Uncomment to perform snapshot test
    # def test_snap_root_NoTagsSpecifications1Of2(self):
    #     # Arrange
    #     instance_json = json.load(open("tests/test_data/test_data_instance_for_snapshot_01.json"))
    #     tags_specifications = None

    #     # Act
    #     instance = Instance(instance_json)
    #     snapshot = instance.snap_root(tags_specifications=tags_specifications)
    #     print(f"test_snap_root_NoTagsSpecifications1Of2: {snapshot}")

    #     assert False
    
    # Uncomment to perform snapshot test
    # def test_snap_root_NoTagsSpecifications2Of2(self):
    #     # Arrange
    #     instance_json = json.load(open("tests/test_data/test_data_instance_for_snapshot_03.json"))
    #     tags_specifications = []

    #     # Act
    #     instance = Instance(instance_json)
    #     snapshot = instance.snap_root(tags_specifications=tags_specifications)
    #     print(f"test_snap_root_NoTagsSpecifications2Of2: {snapshot}")

    #     assert False
    
    # Uncomment to perform snapshot test
    # def test_snap_all_NormalValues(self):
    #     # Arrange
    #     instance_json = json.load(open("tests/test_data/test_data_instance_for_snapshot_01.json"))
    #     tags_specifications = [{
    #         "Key": "CreatorName",
    #         "Value": "mervin.hemaraju@checkout.com"
    #     }]

    #     # Act
    #     instance = Instance(instance_json)
    #     snapshots = instance.snap_all(tags_specifications)
    #     print(f"test_snap_all_NormalValues: {snapshots}")

    #     assert False

    # Uncomment to perform snapshot test
    # def test_snap_all_NoTagsSpecifications(self):
    #     # Arrange
    #     instance_json = json.load(open("tests/test_data/test_data_instance_for_snapshot_02.json"))

    #     # Act
    #     instance = Instance(instance_json)
    #     snapshots = instance.snap_all()
    #     print(f"test_snap_all_NoTagsSpecifications: {snapshots}")

    #     assert False

    def test_load_instance_NoTagsDefined(self):
        # Arrange
        instance_json = json.load(open("tests/test_data/test_data_instance_no_tags.json"))
        expected_id = "i-009ced0eee26e121d"
        expected_private_ip = "172.31.255.20"
        expected_root_volume = "vol-0ab3909a5663e3a0c"
        expected_volumes = ["vol-0ab3909a5663e3a0c", "vol-0f3e69129f69e362f", "vol-0b4faf065769820dd", "vol-01f7d821d55743bfc"]
        expected_name = None

        # Act
        instance = Instance(instance_json)
        result_private_ip = instance.private_ip
        result_root_volume = instance.root_volume
        result_volumes = instance.volumes
        result_name = instance.name
        result_id = instance.id

        assert result_private_ip == expected_private_ip
        assert result_root_volume == expected_root_volume
        assert result_volumes == expected_volumes
        assert result_name == expected_name
        assert result_id == expected_id

    def test_load_instance_NoNameTagDefined(self):
        # Arrange
        instance_json = json.load(open("tests/test_data/test_data_instance_no_name.json"))
        expected_id = "i-009ced0eee26e121d"
        expected_private_ip = "172.31.255.20"
        expected_root_volume = "vol-0ab3909a5663e3a0c"
        expected_volumes = ["vol-0ab3909a5663e3a0c", "vol-0f3e69129f69e362f", "vol-0b4faf065769820dd", "vol-01f7d821d55743bfc"]
        expected_name = None

        # Act
        instance = Instance(instance_json)
        result_private_ip = instance.private_ip
        result_root_volume = instance.root_volume
        result_volumes = instance.volumes
        result_name = instance.name
        result_id = instance.id

        assert result_private_ip == expected_private_ip
        assert result_root_volume == expected_root_volume
        assert result_volumes == expected_volumes
        assert result_name == expected_name
        assert result_id == expected_id

    def test_load_instance_NoPrivateIpDefined(self):
        # Arrange
        instance_json = json.load(open("tests/test_data/test_data_instance_no_ip.json"))
        expected_id = "i-009ced0eee26e121d"
        expected_private_ip = None
        expected_root_volume = "vol-0ab3909a5663e3a0c"
        expected_volumes = ["vol-0ab3909a5663e3a0c", "vol-0f3e69129f69e362f", "vol-0b4faf065769820dd", "vol-01f7d821d55743bfc"]
        expected_name = "win_jump_pub_01"

        # Act
        instance = Instance(instance_json)
        result_private_ip = instance.private_ip
        result_root_volume = instance.root_volume
        result_volumes = instance.volumes
        result_name = instance.name
        result_id = instance.id

        assert result_private_ip == expected_private_ip
        assert result_root_volume == expected_root_volume
        assert result_volumes == expected_volumes
        assert result_name == expected_name
        assert result_id == expected_id

    def test_load_instance_NoVolumesDefined(self):
        # Arrange
        instance_json = json.load(open("tests/test_data/test_data_instance_no_volumes.json"))
        expected_result = "The instance 172.31.255.20 does not have any volumes."

        # Act
        try:
            instance = Instance(instance_json)
            result = "Failed"
        except Exception as e:
            result = str(e)

        assert expected_result == result

    def test_load_instance_NoRootVolumeDefined(self):
        # Arrange
        instance_json = json.load(open("tests/test_data/test_data_instance_no_root_volume.json"))
        expected_id = "i-009ced0eee26e121d"
        expected_private_ip =  "172.31.255.20"
        expected_root_volume = None
        expected_volumes = ["vol-0f3e69129f69e362f", "vol-0b4faf065769820dd", "vol-01f7d821d55743bfc"]
        expected_name = "win_jump_pub_01"

        # Act
        instance = Instance(instance_json)
        result_private_ip = instance.private_ip
        result_root_volume = instance.root_volume
        result_volumes = instance.volumes
        result_name = instance.name
        result_id = instance.id

        assert result_private_ip == expected_private_ip
        assert result_root_volume == expected_root_volume
        assert result_volumes == expected_volumes
        assert result_name == expected_name
        assert result_id == expected_id

    def test_load_instance_AllAttributesPresent(self):
        # Arrange
        instance_json = json.load(open("tests/test_data/test_data_instance_all_attributes.json"))
        expected_id = "i-009ced0eee26e121d"
        expected_private_ip = "172.31.255.20"
        expected_root_volume = "vol-0ab3909a5663e3a0c"
        expected_volumes = ["vol-0ab3909a5663e3a0c", "vol-0f3e69129f69e362f", "vol-0b4faf065769820dd", "vol-01f7d821d55743bfc"]
        expected_name = "win_jump_pub_01"

        # Act
        instance = Instance(instance_json)
        result_private_ip = instance.private_ip
        result_root_volume = instance.root_volume
        result_volumes = instance.volumes
        result_name = instance.name
        result_id = instance.id

        assert result_private_ip == expected_private_ip
        assert result_root_volume == expected_root_volume
        assert result_volumes == expected_volumes
        assert result_name == expected_name
        assert result_id == expected_id

    def test_snap_root_NoRootVolumeDefined(self):
        # Arrange
        instance_json = json.load(open("tests/test_data/test_data_instance_no_root_volume.json"))
        expected_result = Consts.EXCEPTION_MESSAGE_ROOT_VOLUME_NOT_FOUND

        # Act
        try:
            instance = Instance(instance_json)
            result = instance.snap_root([])
        except Exception as e:
            result = str(e)

        assert expected_result == result


import boto3
import  snappy.utils.constants as Consts
from snappy.instance import Instance
from snappy.utils import helper as Helper

class Snappy():        
        
    def __init__(self, instances):

        # Create an empty list of instances
        self.instances = []

        # Create the boto3 EC2 client
        client = boto3.client('ec2')

        # Organize obtained instances into ip_addresses and hostnames
        ip_addresses, hostnames = Helper.organize_instances(instances)
        
        # Verify if IP addresses obtained
        if ip_addresses:
            # Get instance description from ip addresses
            response_ips = client.describe_instances(
                Filters=Consts.filter_boto3_template_ip(ip_addresses)
            )
            
            # Filter and append Instances from ip addresses
            for r in response_ips['Reservations']:

                for i in r['Instances']:

                    self.instances.append(Instance(i))
        
        # Verify if hostnames obtained
        if hostnames:  
            # Get instance description from hostname
            response_hostnames = client.describe_instances(
                Filters=Consts.filter_boto3_template_hostname(hostnames)
            )

            # Filter and append Instances from hostnames
            for r in response_hostnames['Reservations']:

                for i in r['Instances']:

                    self.instances.append(Instance(i))
                    
        
        # Retrieve instances that were unable to fetch
        failed_instances = Helper.retrieve_failed_instances(instances, self.instances)
        
        # Check if there are failed instances
        if failed_instances:
            # Raise the exception
            raise Exception(Consts.EXCEPTION_MESSAGE_INSTANCES_RETRIEVAL_FAILED.format(str(failed_instances)))
        
        # Remove duplicate instances
        self.instances = Helper.remove_duplicate_instances(self.instances)
        
    def snap_roots(self, tags_specifications=None):
        # Make root snapshots for each instances and return the list of output
        return [instance.snap_root(tags_specifications) for instance in self.instances]


###############################################################
############## All constants values resides here ##############
###############################################################


#################################################
############## TEMPLATES & FILTERS ##############
#################################################

def template_snapshot_tag_timestamp(date, name):
    return {
        "Key": "Name",
        "Value": f"{date}_{name}_snapshot"
    }
    
def template_snapshot_output(snapshot_id, for_instance, volume_id):
    return {
        "SnapshotID": snapshot_id,
        "InstanceName": for_instance,
        "VolumeID": volume_id,
    }

def filter_boto3_template_ip(instances):
    return [{
        'Name': 'private-ip-address',
        'Values': instances,
    }]

def filter_boto3_template_hostname(hostname):
    return [{
        'Name': 'tag:Name',
        'Values': hostname,
    }]
    
######################################
############## MESSAGES ##############
######################################
MESSAGE_DESCRIPTION_SNAPSHOT = 'Snapshot for {}'


########################################
############## EXCEPTIONS ##############
########################################
EXCEPTION_MESSAGE_VOLUMES_NOT_FOUND = "The instance {} does not have any volumes."
EXCEPTION_MESSAGE_ROOT_VOLUME_NOT_FOUND = "This instance does not have a root volume"
EXCEPTION_MESSAGE_INSTANCES_RETRIEVAL_FAILED = "The following instances could not be retrieved: {}"


import boto3
import snappy.utils.constants as Consts
from snappy.utils import helper as Helper

class Instance:

    def __init__(self, json) -> None:

        # Declare empty values 
        self.id = json["InstanceId"]
        self.name = None
        self.private_ip = None
        self.root_volume = None
        self.volumes = None

        # Retrieve instance name
        if "Tags" in json:

            for tag in json["Tags"]:

                if(tag["Key"].lower() == "name"):

                    self.name = tag["Value"]
        
        # Retrieve IP Address
        if "PrivateIpAddress" in json:

            self.private_ip = json["PrivateIpAddress"]


        # Retrieve volume IDs

        # Check if volumes exists before continuing
        if "BlockDeviceMappings" not in json:
            raise Exception(Consts.EXCEPTION_MESSAGE_VOLUMES_NOT_FOUND.format(self.private_ip))

        # Get the root volume device name
        if "RootDeviceName" in json:
            root_volume_device_name = json["RootDeviceName"]

            # Filter the root volume ID
            root_volume_data = next((filter(lambda t: t["DeviceName"] == root_volume_device_name, json["BlockDeviceMappings"])), None)
        
            if root_volume_data is not None:
                self.root_volume = root_volume_data["Ebs"]["VolumeId"]

        # Get all volume IDs
        self.volumes = [volume["Ebs"]["VolumeId"] for volume in json["BlockDeviceMappings"]]

    def snap_root(self, tags_specifications=None) -> str:
        
        # Check if root volume is present
        if self.root_volume is None:
            raise Exception(Consts.EXCEPTION_MESSAGE_ROOT_VOLUME_NOT_FOUND)

        # Create EC2 client 
        client = boto3.client('ec2')

        # Define Mandatory Tags
        mandatory_tags = [Consts.template_snapshot_tag_timestamp(Helper.format_today(), self.name)]
        
        # Reformat tags scpefications
        if tags_specifications != None and tags_specifications != []:
            
            # Add passed tags
            mandatory_tags = mandatory_tags + tags_specifications
            
            formated_tags_specs = [
                {
                    'ResourceType': 'snapshot',
                    'Tags': mandatory_tags
                },
            ]
            
        else:
            formated_tags_specs = [
                {
                    'ResourceType': 'snapshot',
                    'Tags': mandatory_tags
                },
            ]
            
        # Create snapshot
        response = client.create_snapshot(
            Description=Consts.MESSAGE_DESCRIPTION_SNAPSHOT.format(self.name) if self.name != None else Consts.MESSAGE_DESCRIPTION_SNAPSHOT.format(self.private_ip),
            VolumeId=self.root_volume,
            TagSpecifications=formated_tags_specs
        )
        
        # Return the output
        return Consts.template_snapshot_output(response["SnapshotId"], self.name, self.root_volume)

    def snap_all(self, tags_specifications=None):

        # Create EC2 client 
        client = boto3.client('ec2')

        # Reformat tags scpefications
        if tags_specifications != None and tags_specifications != []:
            formated_tags_specs = [
                {
                    'ResourceType': 'snapshot',
                    'Tags': tags_specifications
                },
            ]
        else:
            formated_tags_specs = []

        # Create a snapshot description
        if self.name != None:
            snapshot_description = Consts.MESSAGE_DESCRIPTION_SNAPSHOT.format(self.name)
        else:
            snapshot_description = Consts.MESSAGE_DESCRIPTION_SNAPSHOT.format(self.private_ip)

        # Create snapshots
        response = client.create_snapshots(
            Description=snapshot_description,
            InstanceSpecification={
                'InstanceId': self.id,
                'ExcludeBootVolume': False
            },
            TagSpecifications=formated_tags_specs
        )
        
        # Return the snapshot ID list
        return response["Snapshots"]


            




        


from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as rm:
    long_description = rm.read()

setup(
    name="aws-snappy",
    version="0.3",
    author="Mervin Hemaraju",
    author_email="mervin.hemaraju@checkout.com",
    description="Snappy is a Python library that facilitates taking root volume snapshots as well as non root volume snapshot from an instance.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/mervin-hemaraju-cko/snappy",
    packages=find_packages(exclude=('tests')),
    install_requires=[
          'boto3'
      ],
    test_suite="tests",
    python_requires=">=3.7",
)